@@ -4,8 +4,8 @@ package Task::Kensho::Config;
 BEGIN {
   $Task::Kensho::Config::AUTHORITY = 'cpan:PERIGRIN';
 }
-# git description: v0.34004-TRIAL-21-gc652f76
-$Task::Kensho::Config::VERSION = '0.35';
+# git description: v0.35-24-g83ca58f
+$Task::Kensho::Config::VERSION = '0.36';
 # ABSTRACT: A Glimpse at an Enlightened Perl: Config Modules
 
 __END__
@@ -20,7 +20,7 @@ Task::Kensho::Config - A Glimpse at an Enlightened Perl: Config Modules
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ subject and object."[3]
 
 =back
 
-L<Task::Kensho> is a first cut at building a list of recommended modules
+L<Task::Kensho> is a list of recommended modules
 for Enlightened Perl development. CPAN is wonderful, but there are too
 many wheels and you have to pick and choose amongst the various
 competing technologies.
@@ -87,7 +87,7 @@ regarding which modules you wish to install.
 
 The C<cpanm> client requires interactive mode to be enabled for this to work:
 
-    cpanm --interactive Task-Kensho
+    cpanm --interactive Task::Kensho::Config
 
 =head1 BUGS AND LIMITATIONS
 
